@@ -7,6 +7,7 @@ import Data.Map.Strict (Map)
 import Control.Monad.Trans.State (State, state, runState, put, get)
 import LatexRenderer
 import WikiHelper
+import WikiLinkHelper
 import Tools
 import Data.Char
 import Text.Printf
@@ -304,10 +305,14 @@ treeToHtml2 ll
                d <- treeToHtml2 (breakLines3 linewidth g)
                return $ (rtrim d)
         nodeToHtml (Environment Template (Str s) l) = templateToHtml l s
+        nodeToHtml (Environment Wikitable (TagAttr _ m) l)
+          = walk ("<table "++ (writedict (Map.toList m))++" ><tr>") l "</tr></table>"
         nodeToHtml (Environment Wikitable _ l)
-          = walk "<table><tr>" l "</table></tr>"
+          = walk "<table><tr>" l "</tr></table>"
         nodeToHtml (Environment TableRowSep _ _) = return "</tr><tr>"
-        nodeToHtml (Environment TableColSep _ _) = return "</td><td>"
+        nodeToHtml (Environment TableColSep (TagAttr _ m) _) = return ("</td><td "++(writedict (Map.toList m)) ++" >")
+
+        nodeToHtml (Environment TableColSep _ _) = return ("</td><td>")
         nodeToHtml (Environment TableHeadColSep _ _) = return "</th><th>"
         nodeToHtml (Environment TableCap _ l)
           = walk "<caption>" l "</caption>"
@@ -324,9 +329,11 @@ treeToHtml2 ll
         nodeToHtml (Item _) = return "</li><li>"
         nodeToHtml (Environment Tag (TagAttr "noscript" _) _) = return []
         nodeToHtml (Environment Tag (TagAttr "head" _) _) = return []
-        nodeToHtml (Environment Tag (TagAttr "a" _) l) = walk "" l ""
+        nodeToHtml (Environment Tag (TagAttr "a" m) l) = do st<-get
+                                                            walk ("<a " ++ (writedict (Map.toList (Map.update (\r-> if (take 5 r) == "/wiki" then Just (wikiUrlDataToString (urld st) r) else Just r) "href" m))) ++ ">") l  ("</a>")
         nodeToHtml (Environment Tag (TagAttr "body" _) l) = walk "" l ""
         nodeToHtml (Environment Tag (TagAttr "html" _) l) = walk "" l ""
+        nodeToHtml (Environment NumHtml (Str s) l) = walk ("&#"++s++";") l ""
         nodeToHtml (Environment Tag (TagAttr "div" a) l)
           = if (Map.member "class" a) then
               if
