@@ -27,7 +27,7 @@ import Control.Monad.Except
 import System.Process
 import HtmlParser (parseHtml)
 import Data.Serialize as S (encode, decode)
-
+import Data.Maybe (fromMaybe)
 
 
 notendyet ::
@@ -145,12 +145,12 @@ qIncludeAction wurl text
 runqBookIncludeAction :: String -> ImperativeMonad ()
 runqBookIncludeAction dir
   = do t <- liftIO $ B.readFile (dir </> "bookinput")
-       let (cfg,wurl,text,acu)=(case S.decode t of {Right k->k::(FullConfig,WikiUrl,String,Either [FilePath] [Anything Char]);_->undefined})
+       let (cfg,wurl,text,acu,ad,fu)=(case S.decode t of {Right k->k::(FullConfig,WikiUrl,String,Either [FilePath] [Anything Char],[(Map String Contributor)],FullWikiUrl);_->undefined})
        oldst<-get 
-       put oldst{loadacu=acu}
+       put oldst{loadacu=acu,fullUrl=fu}
        _ <- qBookIncludeActionbase cfg wurl text
-       st<-get 
-       liftIO $ B.writeFile (dir </> "bookoutput") (S.encode (loadacu st))
+       st<-get
+       liftIO $ B.writeFile (dir </> "bookoutput") (S.encode (loadacu st,(audict st)++ad))
 
 
 qBookIncludeActionbase :: FullConfig-> WikiUrl -> String ->  ImperativeMonad String
@@ -186,7 +186,7 @@ qBookIncludeAction :: FullConfig-> WikiUrl -> String ->  ImperativeMonad String
 qBookIncludeAction cfg wurl text 
   = do sst <- get
        case (loadacu sst) of
-        Right _ ->   if isInfixOf "Vorlage" text then return ("{{" ++ text ++ "}}") else if isInfixOf "Category:" text then return "" else
+        Right _ ->   if isInfixOf "Vorlage" text then return ("{{" ++ text ++ "}}") else if isInfixOf "Category:" text then return "" else if (noparent cfg) && case text of {'/':_->False; _->True} &&(fromMaybe False (wurl >>= (return.not.((flip Data.List.isPrefixOf) text).(intercalate "/").(Data.List.dropWhile (=="wiki")).(splitOn "/").url_path.fst))) then return "" else
                         do pp <- (liftIO (print d)) >> myfun
                            case pp of
                             Just p -> do _ <- addContributors d Nothing
@@ -194,7 +194,7 @@ qBookIncludeAction cfg wurl text
                                          st <- get
                                          systempdir <- liftIO getTemporaryDirectory
                                          tempdir <- liftIO $ createTempDirectory systempdir "MediaWiki2LaTeXParser"
-                                         --liftIO ( Tools.writeFile (t2empdir </> "input") x)
+                                         liftIO ( Tools.writeFile (tempdir </> "input") x)
                                          _ <- liftIO $ system ("mediawiki2latex -x " ++   (Hex.hex (show (fullconfigbase{compile = Just tempdir, runMode= runMode cfg}))))
                                          case (loadacu st) of
                                           Right base -> do t <- liftIO $ B.readFile (tempdir </> "output")
@@ -202,14 +202,15 @@ qBookIncludeAction cfg wurl text
                                           Left base -> put st{loadacu = Left (tempdir: base)}
                                          return x
                             _ -> return  ""
-        Left _ ->    do systempdir <- liftIO getTemporaryDirectory
+        Left _ -> if isInfixOf "Vorlage" text then return ("{{" ++ text ++ "}}") else if isInfixOf "Category:" text then return "" else if (noparent cfg)&& case text of {'/':_->False; _->True} && (fromMaybe False (wurl >>= (return.not.((flip Data.List.isPrefixOf) text).(intercalate "/").(Data.List.dropWhile (=="wiki")).(splitOn "/").url_path.fst))) then return "" else
+                     do systempdir <- liftIO getTemporaryDirectory
                         tempdir <- liftIO $  createTempDirectory systempdir "MediaWiki2LaTeXBook"
-                        liftIO $ B.writeFile (tempdir </> "bookinput") (S.encode (cfg,wurl,text,loadacu sst))
+                        liftIO $ B.writeFile (tempdir </> "bookinput") (S.encode (cfg,wurl,text,loadacu sst,audict sst,fullUrl sst))
                         _ <- liftIO $ system ("mediawiki2latex -x " ++  (Hex.hex (show (fullconfigbase{convert = Just (NewLoad tempdir)}))))
                         t <- liftIO $ B.readFile (tempdir </> "bookoutput")
                         oldst<-get
-                        let (acu)=(case S.decode t of {Right k->k::Either [FilePath] [Anything Char];_->Right []}) 
-                        put oldst{loadacu=acu}
+                        let (acu,au)=(case S.decode t of {Right k->k::(Either [FilePath] [Anything Char],[(Map String Contributor)]);_->(Right [],[])}) 
+                        put oldst{loadacu=acu,audict=au}
                         return []
 
                        
@@ -369,7 +370,7 @@ getContributors u
 
 addContributors ::
                 [Char] -> Maybe URL -> ImperativeMonad ((Maybe String))
-addContributors theLemma uu
+addContributors theLemma uu 
   = do sst <- get
        let st = fullUrl sst
        thetheLemma <- liftIO $ return theLemma
@@ -400,6 +401,7 @@ addContributors theLemma uu
                 Nothing -> Just Contributor{name = a, href = h, edits = e}
                 Just old -> Just old{edits = (edits old) + e}
 
+
 noinclude :: t -> String -> ImperativeMonad [Char]
 noinclude wurl
   = runAction "<noinclude>" "</noinclude>" (zeroAction wurl)
