@@ -536,7 +536,7 @@ goodtags1
   = ["includeonly", "references", "blockquote", "noinclude",
      "noframes", "frameset", "colgroup", "fieldset", "basefont",
      "!DOCTYPE", "noscript", "address", "acronym", "caption", "strong",
-     "applet", "script", "button", "select", "section", "legend",
+     "applet", "script", "button", "select", "section", "legend", "footer",
      "strike", "object", "input", "center", "legend", "iframe", "small",
      "video", "audio", "style", "input", "label", "tbody", "thead",
      "title", "track" ,"frame", "param", "base", "area", "font", "code", "span",
